aboutsummaryrefslogtreecommitdiff
path: root/discord/member.py
diff options
context:
space:
mode:
Diffstat (limited to 'discord/member.py')
-rw-r--r--discord/member.py7
1 files changed, 6 insertions, 1 deletions
diff --git a/discord/member.py b/discord/member.py
index b9d1ffa7..dbcbc492 100644
--- a/discord/member.py
+++ b/discord/member.py
@@ -309,7 +309,7 @@ class Member(discord.abc.Messageable, _BaseUser):
return try_enum(Status, self._client_status.get('web', 'offline'))
def is_on_mobile(self):
"""A helper function that determines if a member is active on a mobile device."""
return 'mobile' in self._client_status
@property
@@ -395,6 +395,11 @@ class Member(discord.abc.Messageable, _BaseUser):
-----------
message: :class:`Message`
The message to check if you're mentioned in.
+
+ Returns
+ -------
+ :class:`bool`
+ Indicates if the member is mentioned in the message.
"""
if message.guild is None or message.guild.id != self.guild.id:
return False
@@ -309,7 +309,7 @@ class Member(discord.abc.Messageable, _BaseUser):
return try_enum(Status, self._client_status.get('web', 'offline'))
def is_on_mobile(self):
- """A helper function that determines if a member is active on a mobile device."""
+ """:class:`bool`: A helper function that determines if a member is active on a mobile device."""
return 'mobile' in self._client_status